@@ -1126,6 +1126,7 @@ pub fn mock_process_instruction(
 mod tests {
     use {
         super::*,
+        crate::compute_budget,
         serde::{Deserialize, Serialize},
         solana_sdk::{
             account::{ReadableAccount, WritableAccount},
@@ -1671,14 +1672,14 @@ mod tests {
         feature_set.deactivate(&requestable_heap_size::id());
         let mut invoke_context = InvokeContext::new_mock(&accounts, &[]);
         invoke_context.feature_set = Arc::new(feature_set);
-        invoke_context.compute_budget = ComputeBudget::new(false);
+        invoke_context.compute_budget = ComputeBudget::new(compute_budget::DEFAULT_UNITS);
 
         invoke_context
             .push(&noop_message, &noop_message.instructions()[0], &[0], &[])
             .unwrap();
         assert_eq!(
             *invoke_context.get_compute_budget(),
-            ComputeBudget::new(false)
+            ComputeBudget::new(compute_budget::DEFAULT_UNITS)
         );
         invoke_context.pop();
 
@@ -1688,7 +1689,7 @@ mod tests {
         let expected_compute_budget = ComputeBudget {
             max_units: 500_000,
             heap_size: Some(256_usize.saturating_mul(1024)),
-            ..ComputeBudget::new(false)
+            ..ComputeBudget::new(compute_budget::DEFAULT_UNITS)
         };
         assert_eq!(
             *invoke_context.get_compute_budget(),
@@ -1701,7 +1702,7 @@ mod tests {
             .unwrap();
         assert_eq!(
             *invoke_context.get_compute_budget(),
-            ComputeBudget::new(false)
+            ComputeBudget::new(compute_budget::DEFAULT_UNITS)
         );
         invoke_context.pop();
     }
